==> haskell-microlens-mtl-0.2.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
key:                  microlens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  ecc1c5c4850143e8eead15598839fda1
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
depends:
    base-4.15.0.0 microlens-0.4.12.0-IoK2ncpVKVzEwRUasmz5D3 mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-mtl-0.2.0.2-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.2
visibility:           public
id:                   microlens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
key:                  microlens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.com>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  1532708086125ddb2c8e1785acf16de7
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-mtl-0.2.0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-mtl-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-mtl
hs-libraries:         HSmicrolens-mtl-0.2.0.2-Fvlx11Ndss4INlVisPiItr
depends:
    base-4.15.1.0 microlens-0.4.13.0-8kbZITwqGed8vNsPXOVOwI mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
